//
//  Payment.swift
//  RoomscannerApp
//
//  Created by Asil Arslan on 28.08.2023.
//

import Foundation
import SwiftUI


struct Payment: Identifiable{
    let id = UUID()
    let paymentId: String
    var title: String
    var index: Int
    var price: Double = 0
    var priceLocale: String
    var discount: String
    var extraInfo: String
    var unit: String
    var duration: String
    var locale: Locale = Locale.current
    var isTrialAvailable = false
    var trialPrice = ""
    var currency = "USD"
    
    init(paymentId: String, title: String, index: Int, price: String, discount: String, extraInfo: String, unit: String, duration: String){
        self.paymentId = paymentId
        self.title = title
        self.index = index
        self.priceLocale = price
        self.discount = discount
        self.extraInfo = extraInfo
        self.unit = unit
        self.duration = duration
    }
}

extension Payment{

    func monthlyPrice() -> String{
        let monthly: Double = price/12
        let formatter = NumberFormatter()
        formatter.numberStyle = .currency
        formatter.locale = locale
        return formatter.string(from: monthly as NSNumber)!
    }

}


