//
//  MonthlyPlanView.swift
//  WordPress
//
//  Created by Studio on 1.01.2023.
//

import SwiftUI

struct MonthlyPlanView: View {
    
    @EnvironmentObject var paymentViewModel: PaymentViewModel
    @Binding var selectedPlan: PremiumPlan
    let plan: PremiumPlan = .monthly
    var paymentId: String
    
    var body: some View {
        HStack(spacing: 16) {
            if selectedPlan == plan {
                Image.checkmarkCircleIcon
                    .resizable()
                    .frame(width: 30, height: 30)
                    .foregroundColor(.darkOrange)
            } else {
                Image.circleIcon
                    .resizable()
                    .frame(width: 30, height: 30)
                    .foregroundColor(.darkOrange)
            }
            
            if let product = paymentViewModel.payments.filter( {$0.paymentId == paymentId}).first {
                Text("\(product.duration) \(product.priceLocale)")
                    .font(.system(size: 20, weight: .semibold))
            }
            
            
            Spacer()
        }
        .frame(maxWidth: .infinity)
        .frame(height: 80)
        .padding(.horizontal, 20)
        .overlay(
            RoundedRectangle(cornerRadius: 12)
                .stroke(selectedPlan == plan ? Color.darkOrange : Color.clear, lineWidth: 4)
        )
        .background(Color(uiColor: .secondarySystemGroupedBackground))
        .cornerRadius(12)
        .padding(.horizontal, 20)
        .onTapGesture {
            selectedPlan = plan
            paymentViewModel.selectedProductId = paymentId
        }
    }
}

struct MonthlyPlanView_Previews: PreviewProvider {
    static var previews: some View {
        MonthlyPlanView(selectedPlan: .constant(.yearly), paymentId: AppConfig.MONTHLY_PRODUCT_ID)
    }
}
