//
//  YearlyPlanView.swift
//  WordPress
//
//  Created by Studio on 1.01.2023.
//

import SwiftUI

struct YearlyPlanView: View {
    @EnvironmentObject var paymentViewModel: PaymentViewModel
    @Binding var selectedPlan: PremiumPlan
    let plan: PremiumPlan = .yearly
    var paymentId: String
    
    var body: some View {
        ZStack {
            HStack(spacing: 16) {
                if selectedPlan == plan {
                    Image.checkmarkCircleIcon
                        .resizable()
                        .frame(width: 30, height: 30)
                        .foregroundColor(.darkOrange)
                } else {
                    Image.circleIcon
                        .resizable()
                        .frame(width: 30, height: 30)
                        .foregroundColor(.darkOrange)
                }
                VStack(alignment: .leading, spacing: 2) {
                    if let product = paymentViewModel.payments.filter( {$0.paymentId == paymentId}).first {
                        HStack {
                            Text("\(product.duration) \(product.priceLocale)")
                                .font(.system(size: 20, weight: .semibold))
                            Text("(\(product.monthlyPrice())/mo)")
                                .font(.system(size: 14, weight: .regular))
                            Spacer()
                        }
                        if product.isTrialAvailable {
                            Text(product.trialPrice)
                                .font(.system(size: 14, weight: .regular))
                        }
                        
                    }
                }
                Spacer()
            }
            .frame(maxWidth: .infinity)
            .frame(height: 80)
            .padding(.horizontal, 20)
            .overlay(
                RoundedRectangle(cornerRadius: 12)
                    .stroke(selectedPlan == plan ? Color.darkOrange : Color.clear, lineWidth: 4)
            )
            .background(Color(uiColor: .secondarySystemGroupedBackground))
            .cornerRadius(12)
            .padding(.horizontal, 20)
            
            VStack {
                HStack {
                    Spacer()
                    Text("Save \(String(format: "%.2f", paymentViewModel.saveValue()))%")
                        .font(.system(size: 14, weight: .medium))
                        .padding(8)
                        .background(Color.darkOrange)
                        .foregroundColor(.white)
                        .cornerRadius(6)
                        .opacity(selectedPlan == plan ? 1 : 0)
                }.padding(.horizontal, 40).padding(.top, -12)
                Spacer()
            }
            .frame(maxWidth: .infinity)
            .frame(height: 80)
        }
        .onTapGesture {
            selectedPlan = plan
            paymentViewModel.selectedProductId = paymentId
        }
    }
}

struct YearlyPlanView_Previews: PreviewProvider {
    static var previews: some View {
        YearlyPlanView(selectedPlan: .constant(.yearly), paymentId: AppConfig.YEARLY_PRODUCT_ID)
    }
}
