//
//  RoomCaptureController.swift
//  RoomscannerApp
//
//  Created by Asil Arslan on 15.08.2023.
//

import Foundation
import RoomPlan
import UniformTypeIdentifiers

class RoomCaptureController : ObservableObject, RoomCaptureViewDelegate, RoomCaptureSessionDelegate
{
    static var instance = RoomCaptureController()
    
    @Published var roomCaptureView: RoomCaptureView
    @Published var showExportButton = false
    @Published var showShareSheet = false
    @Published var exportUrl: URL?
    
    var sessionConfig: RoomCaptureSession.Configuration
    var finalResult: CapturedRoom?
    
    init() {
        roomCaptureView = RoomCaptureView(frame: CGRect(x: 0, y: 0, width: 42, height: 42))
        sessionConfig = RoomCaptureSession.Configuration()
        roomCaptureView.captureSession.delegate = self
        roomCaptureView.delegate = self
    }
    
    
    
    
    func startSession() {
        roomCaptureView.captureSession.run(configuration: sessionConfig)
    }
    
    func stopSession() {
        roomCaptureView.captureSession.stop()
    }
    
    func captureView(shouldPresent roomDataForProcessing: CapturedRoomData, error: Error?) -> Bool {
        return true
    }
    
    func captureView(didPresent processedResult: CapturedRoom, error: Error?) {
        finalResult = processedResult
    }
    
    func export() {
        if let finalResult{
            let fm = FileManager.default
            var path = fm.urls(for: .documentDirectory, in: .userDomainMask).first!
            let fileName = "\(UUID().uuidString).usdz"
            path.appendPathComponent(fileName)
            exportUrl = path.absoluteURL
            do{
                try finalResult.export(to: exportUrl!)
            }
            catch{
                print(error)
            }
            
        }
        showShareSheet = true
    }
    
    
    
    func save(roomName: String) {
        
        let fileName = "\(roomName).usdz"
        exportUrl = FileManager.default.urls(for: .documentDirectory, in: .userDomainMask).first!.appending(path: fileName)
        do {
            try finalResult?.export(to: exportUrl!)
        } catch {
            print("Error exporting usdz scan.")
            return
        }
        
    }
    
    required init?(coder: NSCoder) {
        fatalError("Not needed.")
    }
    
    func encode(with coder: NSCoder) {
        fatalError("Not needed.")
    }
}

