//
//  RoomsView.swift
//  RoomscannerApp
//
//  Created by Asil Arslan on 27.08.2023.
//

import SwiftUI
import SceneKit
import AppTrackingTransparency
import AdSupport

struct RoomsView: View {
    @State var scannedModels = [ScannedModel]()
    @State var showSnanner = false
    @State var showSettings = false
    @State var showSubscription = false
    
    init(){
        self.requestIDFA()

    }
    
    func requestIDFA() {
        DispatchQueue.main.asyncAfter(deadline: .now() + 1) {
                    if #available(iOS 14, *) {
                        ATTrackingManager.requestTrackingAuthorization(completionHandler: { status in
                          // Tracking authorization completed. Start loading ads here.
                          // loadAd()
                            if AppUserDefaults.shouldShowInitScreen {
                                
                            }
                        })
                    }
        }
      
    }
    
    
    var body: some View {
        
        NavigationView {
            ZStack {
                

                
                NavigationLink(destination: ScanningView(), isActive: $showSnanner) {
                    EmptyView()
                }
                NavigationLink(destination: SettingsView(), isActive: $showSettings) {
                    EmptyView()
                }
                
                if scannedModels.count == 0 {                    
                    Color(UIColor.systemGroupedBackground).edgesIgnoringSafeArea(.all)
                    NoDataView()
                        .edgesIgnoringSafeArea(.all)
                }else{
                    List{
                        ForEach(scannedModels) { item in
                            
                            
                            NavigationLink(destination: RoomDetailView(scannedModel: item), label: {
                                HStack {
                                    SceneView(scene: try! SCNScene(url:  URL(string:item.filePath)!),
                                              options: [.autoenablesDefaultLighting])
                                    .frame(width: 50,height: 50)
                                    VStack(alignment:.leading) {
                                        Text(URL(string:item.filePath)!.deletingPathExtension().lastPathComponent)
                                            .fontWeight(.semibold)
                                        Text("\(self.getFileCreationDate(path: URL(string:  item.filePath)!)!)")
                                            .font(.footnote)
                                    }
                                    .foregroundColor(.primary)
                                }
                            })
                            
                            
                        }
                    }
                }
            }
            .navigationBarTitle("Scanned Rooms")
            .toolbar(content: {
                ToolbarItem(placement: .navigationBarLeading) {
                    
                    HStack{
                        Button{
                            withAnimation{
                                showSettings.toggle()
                            }
                        }label: {
                            Image(systemName: "gear")
                        }
                        if !AppUserDefaults.isPremiumUser {
                            Button{
                                withAnimation{
                                    showSubscription.toggle()
                                }
                            }label: {
                                Image(systemName: "crown")
                            }
                        }
                        
                    }
                    
                }
                ToolbarItem(placement: .navigationBarTrailing) {
                    Button{
                        withAnimation{
                            
                            if !AppUserDefaults.isPremiumUser && (AppUserDefaults.counter >= AppConfig.ROOM_SCAN_LIMIT ) {
                                showSubscription .toggle()
                                return
                            }
                            
                            AppUserDefaults.counter += 1
                            
                            showSnanner.toggle()
                        }
                    } label: {
                        Label("Add", systemImage: "plus.circle")
                    }
                    
                }
            })
            .onAppear(){
                
                scannedModels.removeAll()
                getFilePaths()
            }
        }
        .sheet(isPresented: $showSubscription, content: {
            
            PaywallView()
        })
        
        
    }
    
    func getFilePaths(){
        let fm = FileManager.default
        let path = fm.urls(for: .documentDirectory, in: .userDomainMask).first!
        do{
            let content = try fm.contentsOfDirectory(atPath: path.path)
            print(path)
            print(path.absoluteString)
            print(path.absoluteURL)
            print(path.path(percentEncoded: false))
            print(content)
            for c in content{
                print(c)
                print(path.appendingPathComponent(c).absoluteString)
                self.scannedModels.append(ScannedModel(filePath: path.appendingPathComponent(c).absoluteString, creationDate: "\(try! fm.attributesOfItem(atPath: path.appendingPathComponent(c).path)[.creationDate] as? NSDate)"))
            }

            
        }
        catch{
            print(error)
        }
    }
    
    func getFileCreationDate(path: URL) -> String?{
        do{
            if let date = try FileManager.default.attributesOfItem(atPath: path.path(percentEncoded: false))[.creationDate] as? Date{
                let formatter = DateFormatter()
                //                   formatter.dateFormat = "MM/dd/yyyy"
                formatter.dateStyle = .short
                formatter.timeStyle = .short
                return formatter.string(from: date)
            }
            
        }
        catch{
            print(error)
        }
        return nil
    }
}

struct RoomsView_Previews: PreviewProvider {
    static var previews: some View {
        RoomsView()
    }
}
