//
//  ScanningView.swift
//  RoomscannerApp
//
//  Created by Asil Arslan on 28.08.2023.
//

import SwiftUI
import RoomPlan

struct ScanningView: View {
    @Environment(\.dismiss) private var dismiss
    @StateObject var captureController = RoomCaptureController.instance
    
    @State private var isSaving = false
    @State private var roomName = ""
    @State private var isScanning = false // Tarama işlemi için yeni durum değişkeni
    
    var body: some View {
        
        ZStack(alignment: .bottom) {
            if isScanning {
                RoomCaptureViewRep()
                    .navigationBarBackButtonHidden(true)
                    .navigationBarItems(leading: Button("Cancel") {
                        captureController.stopSession()
                        dismiss()
                    })
                    .navigationBarItems(trailing: Button("Done") {
                        captureController.stopSession()
                        captureController.showExportButton = true
                    }.opacity(captureController.showExportButton ? 0 : 1)).onAppear() {
                        captureController.showExportButton = false
                        captureController.startSession()
                    }
                
                Button(action: {
                    isSaving.toggle()
                }, label: {
                    Text("Save").font(.title2)
                }).buttonStyle(.borderedProminent).cornerRadius(40).opacity(captureController.showExportButton ? 1 : 0).padding()
                .padding(.bottom)
                .alert("Save", isPresented: $isSaving) {
                    TextField("Room name", text: $roomName)
                    Button("OK", action: {
                        captureController.save(roomName: roomName)
                        dismiss()
                    })
                    Button("Cancel", role: .cancel) { }
                } message: {
                    Text("Please enter room name.")
                }.sheet(isPresented: $captureController.showShareSheet, content:{
                    ActivityViewControllerRep(items: [captureController.exportUrl!])
                })
            } else {
                VStack {
                    Spacer() // Ekranın üst kısmına boşluk bırakmak için
                    Text("Tarama başlamadan önce perdelerinizi açın")
                        .padding(.bottom)
                    Text("Tarama başlamadan kapınızın kapalı olduğundan emin olun.")
                        .padding(.bottom)
                    Text("Tarama için hazır olduğunuz zaman BAŞLA'ya basabilirsiniz")
                        .padding(.bottom)
                    Spacer() // Ekranın alt kısmına boşluk bırakmak için
                    Button(action: {
                        isScanning = true
                    }, label: {
                        Text("BAŞLA").font(.title2)
                    }).buttonStyle(.borderedProminent).cornerRadius(40).padding()
                }
            }
        }
        .edgesIgnoringSafeArea(.all)
    }
}

struct RoomCaptureViewRep : UIViewRepresentable
{
    func makeUIView(context: Context) -> some UIView {
        RoomCaptureController.instance.roomCaptureView
    }
    
    func updateUIView(_ uiView: UIViewType, context: Context) {}
}

struct ActivityViewControllerRep: UIViewControllerRepresentable {
    var items: [Any]
    var activities: [UIActivity]? = nil
    
    func makeUIViewController(context: UIViewControllerRepresentableContext<ActivityViewControllerRep>) -> UIActivityViewController {
        let controller = UIActivityViewController(activityItems: items, applicationActivities: activities)
        return controller
    }
    
    func updateUIViewController(_ uiViewController: UIActivityViewController, context: UIViewControllerRepresentableContext<ActivityViewControllerRep>) {}
}

extension URL {
    var typeIdentifier: String? { (try? resourceValues(forKeys: [.typeIdentifierKey]))?.typeIdentifier }
    var isMP3: Bool { typeIdentifier == "*.txt" }
    var localizedName: String? { (try? resourceValues(forKeys: [.localizedNameKey]))?.localizedName }
    var hasHiddenExtension: Bool {
        get { (try? resourceValues(forKeys: [.hasHiddenExtensionKey]))?.hasHiddenExtension == true }
        set {
            var resourceValues = URLResourceValues()
            resourceValues.hasHiddenExtension = newValue
            try? setResourceValues(resourceValues)
        }
    }
}
